if [ -z ${CONDA_BUILD+x} ]; then
    source /croot/hatch-jupyter-builder_1683742836857/work/build_env_setup.sh
fi
/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin/python -m pip install --no-deps --no-build-isolation . -vv