export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export ARCH="aarch64"
export PREFIX="/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export BUILD_PREFIX="/croot/hatch-jupyter-builder_1683742836857/_build_env"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="linux-aarch64"
export build_platform="linux-aarch64"
export SRC_DIR="/croot/hatch-jupyter-builder_1683742836857/work"
export ROOT="/opt/conda"
export CONDA_PY="311"
export PY3K="1"
export PY_VER="3.11"
export STDLIB_DIR="/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.11"
export SP_DIR="/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.11/site-packages"
export PYTHON="/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin/python"
export NPY_VER="1.23"
export CONDA_NPY="123"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.34"
export CONDA_PERL="5.34"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="hatch-jupyter-builder"
export PKG_VERSION="0.8.3"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/feedstock/recipe"
export CPU_COUNT="3"
export LANG="en_US.UTF-8"
export LC_ALL="en_US.UTF-8"
export SHLIB_EXT=".so"
export PATH="/croot/hatch-jupyter-builder_1683742836857/_build_env/bin:/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin:/opt/conda/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
export HOME="/root"
export PKG_CONFIG_PATH="/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib"
export BUILD="aarch64-conda_cos7-linux-gnu"
export zip_keys="[['python', 'numpy']]"
export ignore_build_only_deps="{'numpy', 'python'}"
export extend_keys="{'ignore_build_only_deps', 'extend_keys', 'ignore_version', 'pin_run_as_build'}"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('libboost', {'max_pin': 'x.x.x'})])"
export cairo="1.16"
export python_implementation="cpython"
export r_implementation="r-base"
export libgd="2.3.3"
export libtiff="4.2"
export openssl="1.1.1"
export libdap4="3.19"
export apr="1.6.3"
export libprotobuf="3.20.3"
export proj4="5.2.0"
export libgsasl="1.8"
export target_platform="linux-aarch64"
export libwebp="1.2.4"
export geos="3.8.0"
export cxx_compiler="gxx"
export dbus="1"
export libnetcdf="4.8"
export cyrus_sasl="2.1.27"
export gst_plugins_base="1.14"
export VERBOSE_AT="V=1"
export libgdal="3.0"
export harfbuzz="4.3.0"
export hdf5="1.10.6"
export cxx_compiler_version="11.2.0"
export fortran_compiler_version="11.2.0"
export c_compiler_version="11.2.0"
export hdfeos2="2.20"
export gmp="6.1"
export proj="6.2.1"
export pixman="0.40"
export llvm_variant="llvm"
export tk="8.6"
export giflib="5"
export xz="5"
export serf="1.3.9"
export icu="68"
export libffi="3.4"
export python_impl="cpython"
export g2clib="1.6"
export openblas="0.3.21"
export VERBOSE_CM="VERBOSE=1"
export hdfeos5="5.1"
export libpng="1.6"
export fortran_compiler="gfortran"
export freetype="2.10"
export zlib="1.2"
export hdf4="4.2"
export r_base="3.5"
export channel_targets="defaults"
export blas_impl="openblas"
export bzip2="1.0"
export boost_cpp="1.73"
export gstreamer="1.14"
export libkml="1.3"
export r_version="3.5.0"
export jpeg="9"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export lzo="2"
export mkl="2023.*"
export cdt_name="amzn2"
export boost="1.73"
export glib="2"
export openjpeg="2.3"
export cpu_optimization_target="nocona"
export c_compiler="gcc"
export libxml2="2.10"
export sqlite="3"
export readline="8.1"
export gnu="2.12.2"
export clang_variant="clang"
export libxslt="1.1"
export mpfr="4"
export zstd="1.5.2"
export rust_compiler="rust"
export rust_compiler_version="1.64.0"
export fontconfig="2.14"
export expat="2"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/croot/hatch-jupyter-builder_1683742836857/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/conda/bin/python' -m conda shell.bash hook)"
conda activate "/croot/hatch-jupyter-builder_1683742836857/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
conda activate --stack "/croot/hatch-jupyter-builder_1683742836857/_build_env"
